IMPORTANT
=========

CONFIGURATION IS UNDERGOING A MAJOR RESTRUCTURING.
THE CURRENT VERSIONS (V22-V24) WILL (ONLY) BE ONE STEP IN THE
DIRECTION THE CONFIGURATION WILL CHANGE TO.
BECAUSE THE STRUCTURE CHANGED, THERE IS NO AUTOMATIC UPDATE
POSSIBLE.
IF YOU HAVE A RUNNING INSTALLED rmtoo THERE IS NO NEED TO UPDATE
DIRECTLY (IF YOU DO NOT NEED ANY OF THE NEW FEATURES).
IF YOU WANT TO USE THE NEW FEATURES, PLEASE FIRST READ THE
DOCUMENTATION (rmtoo-config3(5)).  IF YOU HAVE PROBLEMS WITH THIS
FEEL FREE TO CONTACT OUR SUPPORT AT rmtoo@florath.net


24.5.0
======

User visible changes
--------------------

* Generate traceability matrix from xunit outputs


24.4.1
======

Internal Changes
----------------

* Almost entire project is now configured using pyproject.toml file
* Automatic build and deployment using flit


24.4.0
======

User visible changes
--------------------

* Excel import and export

24.3.4
======

User visible changes
--------------------

* Fixes the issues related to rmtoo, see https://github.com/florath/rmtoo/issues/36

Internal Changes
----------------

* Fix tests for `py38`
* Testing automatic deployment

24.X.Y
======

User visible changes
--------------------

* Fix #7: use id instead of name for subtopics

24.3.0
======

User visible changes
--------------------

* Support for preinstalled virtual machines with GUI


24.2.0
======

User visible changes
--------------------

* Support for preinstalled virtual machines


24.1.5
======

User visible changes
--------------------

* Support for YAML configuration
  This shortens and simplifies configuration.
* Modularization:
  Next level of flexibility.  It is possible to add your
  own input, output or markup classes without changing
  rmtoo itself.
* Experimental support for creating a complete VM
  for rmtoo evaulation and small projects.

Internal Changes
----------------

* Many more code cleanups and refactorings

Status
------

* code coverage: 92%
* pylint: 7.55/10.0
* sonar:  88 code smells, 0.6% duplicates
* code climate: 2.54 GPA, 232 issues

24.0.0
======

User visible changes
--------------------

* Support for python3.
* Support for virtualenv.
* Support for installation with pip (pypi).
* Removed dependency to legacy included versions of other projects
  (async, git, gitdb, odfpy).
* Complete support for UTF-8.


Internal Changes
----------------

* Started pep8 cleanup: many small syntax changes.
* Introduced tox, clean up setup.py, introduced requirements.txt.
* Many, many code cleanups.
* CI / quality checks added: codecov.io, sonarqube.com, covertity,
  codeclimate.com
